@@ -1,6 +1,7 @@
 import os
 from copy import deepcopy
 
+import json
 import numpy as np
 import pandas as pd
 import netCDF4 as nc
@@ -15,7 +16,7 @@ try:
 except:
     from geoenrich.credentials_example import *
     print('Please rename credentials_example.py to credentials.py and fill in the root path and credentials, if needed')
-    print('File location: ' + os.path.split(geoenrich.__file__)[0] + '/credentials_example.py')
+    print('File location: ' + str(Path(geoenrich.__file__).with_name('credentials_example.py')))
 
 
 def get_metadata(ds, varname):
@@ -45,7 +46,10 @@ def get_metadata(ds, varname):
             if 'months since' in ds.variables[name].__dict__['units']:
                 times = num2date(ds.variables[name][:], ds.variables[name].__dict__['units'], '360_day')
             else:
-                times = num2pydate(ds.variables[name][:], ds.variables[name].__dict__['units'])
+                if varname in ['uwnd', 'vwnd']:
+                    times = num2pydate(ds.variables[name][:] - 725563, 'days since 1987-01-01 00:00:00')
+                else:
+                    times = num2pydate(ds.variables[name][:], ds.variables[name].__dict__['units'])
             times = pd.Series([datetime(*d.timetuple()[:-3]) for d in times])
             item = {'name': name, 'standard_name': 'time', 'vals': times, 'unit': None}
             dimdict[name] = item
@@ -114,8 +118,8 @@ def get_var_catalog():
         dict: Dictionary with variable id, variable name in dataset, and dataset url
     """
 
-    path, _ = os.path.split(geoenrich.__file__)
-    var_catalog = pd.read_csv(path + '/data/catalog.csv', index_col = 0).to_dict('index')
+    path = Path(geoenrich.__file__).parent
+    var_catalog = pd.read_csv(path / 'data' / 'catalog.csv', index_col = 0).to_dict('index')
 
     for v in var_catalog:
         var_catalog[v]['var_id'] = v
@@ -142,16 +146,16 @@ def create_nc(var):
         None
     """
 
-    path = sat_path + var['var_id'] + '.nc'
-    pathd = sat_path + var['var_id'] + '_downloaded.nc'
+    path = Path(sat_path, var['var_id'] + '.nc')
+    pathd = Path(sat_path, var['var_id'] + '_downloaded.nc')
 
     remote_ds = nc.Dataset(var['url'])
     varname = var['varname']
     dimdict, var = get_metadata(remote_ds, varname)
 
-    local_ds = nc.Dataset(path, mode = 'w')
+    local_ds = nc.Dataset(str(path), mode = 'w')
     local_ds.set_fill_off()
-    bool_ds = nc.Dataset(pathd, mode = 'w')
+    bool_ds = nc.Dataset(str(pathd), mode = 'w')
 
     for name, dimension in remote_ds.dimensions.items():
         if getattr(remote_ds.variables[name], 'standard_name', 'Unknown') == 'time' or name in ['time', 'time_agg']:
@@ -200,17 +204,17 @@ def create_nc_calculated(var_id):
 
     var_meta = calculated[var_id]
 
-    path = sat_path + var_id + '.nc'
-    pathd = sat_path + var_id + '_downloaded.nc'
+    path = Path(sat_path, var_id + '.nc')
+    pathd = Path(sat_path, var_id + '_downloaded.nc')
 
     var_catalog = get_var_catalog()
-    like_ds = nc.Dataset(sat_path + var_meta['derived_from'][0] + '.nc')
+    like_ds = nc.Dataset(str(Path(sat_path, var_meta['derived_from'][0] + '.nc')))
     like_varname = var_catalog[var_meta['derived_from'][0]]['varname']
     dimdict, var = get_metadata(like_ds, like_varname)
 
-    local_ds = nc.Dataset(path, mode = 'w')
+    local_ds = nc.Dataset(str(path), mode = 'w')
     local_ds.set_fill_off()
-    bool_ds = nc.Dataset(pathd, mode = 'w')
+    bool_ds = nc.Dataset(str(pathd), mode = 'w')
 
     for name, dimension in like_ds.dimensions.items():
         local_ds.createDimension(name, len(dimension) if not dimension.isunlimited() else None)
@@ -374,4 +378,49 @@ def ellipsoid_mask(data, coords, center, geo_buff):
     mask2d = distance > 1
     mask = np.broadcast_to(mask2d, data.shape)
 
-    return(mask)
\ No newline at end of file
+    return(mask)
+
+
+
+class NpEncoder(json.JSONEncoder):
+
+    """
+    Custom encoder to handle numpy data formats in json dump.
+    """
+
+    def default(self, obj):
+        if isinstance(obj, np.integer):
+            return int(obj)
+        if isinstance(obj, np.floating):
+            return float(obj)
+        if isinstance(obj, np.ndarray):
+            return obj.tolist()
+        return super(NpEncoder, self).default(obj)
+
+
+
+def dump_metadata(var_id, out_path=Path('./')):
+
+    """
+    Dump metadata related to the given variable.
+
+    Args:
+        var_id (str): ID of the variable to retrieve metadata for.
+        out_path (str or pathlib.Path): Path where metadata file will be saved.
+
+    Returns:
+        None
+    """
+
+    var = get_var_catalog()[var_id]
+    ds_path = Path(sat_path, var['var_id'] + '.nc')
+
+    ds = nc.Dataset(ds_path)
+    variable = ds[var['varname']]
+    args = {k: variable.getncattr(k) for k in variable.ncattrs()}
+
+    write_path = Path(out_path, f'{var_id}_metadata.json')
+    with (write_path).open('w') as f:
+        json.dump(args, f, ensure_ascii=False, indent=4, cls=NpEncoder)
+
+    print(f"File saved at {write_path}")
\ No newline at end of file
